@@ -1,9 +1,11 @@
 package Geometry::Primitive::Line;
 use Moose;
+use MooseX::Storage;
 
 extends 'Geometry::Primitive';
 
 with qw(Geometry::Primitive::Shape MooseX::Clone);
+with Storage(format => 'JSON', io => 'File');
 
 use overload ('""' => 'to_string');
 
@@ -115,7 +117,7 @@ __END__
 
 =head1 NAME
 
-Geometry::Primitive::Line
+Geometry::Primitive::Line - A Line
 
 =head1 DESCRIPTION
 
